@@ -23,13 +23,13 @@ import warnings
 from pprint import pprint
 
 import httplib2
-import apiclient
 
 import oauth2client
 import oauth2client.file
 import oauth2client.tools
 
 import googleapiclient # to install this : pip install --upgrade google-api-python-client
+import googleapiclient.discovery # to install this : pip install --upgrade google-api-python-client
 
 
 #-------------- Notes on Permission Scope
@@ -177,7 +177,7 @@ class ServiceManager(object):
         if self.api_key:
             # api keys should be used only for personal application and development
             # anyone with the api key can access Google services as the developer
-            discovery = apiclient.discovery.build(api_name, version, developerKey=self.api_key)
+            discovery = googleapiclient.discovery.build(api_name, version, developerKey=self.api_key)
         elif self.oauth_secret_file:
             # engage in OAuth2 authorization and credentialling
 
@@ -189,7 +189,7 @@ class ServiceManager(object):
 
             credentials = self.get_credentials(service_path, permission_scope)
             authorizer = credentials.authorize(httplib2.Http())
-            discovery = apiclient.discovery.build(api_name, version, http=authorizer)
+            discovery = googleapiclient.discovery.build(api_name, version, http=authorizer)
         else:
             raise Exception("Unable to load_service as no authentication models provided. Please specify an API Key or provide OAuth credentials to the googleapps.service.ServiceManager")
 
