@@ -34,6 +34,7 @@ nrow, ncol: the last row and column with any data in it.  Calling this requires
 """
 
 serial_number_base = datetime.datetime(1899,12,30)
+serial_number_base_utc = datetime.datetime(1899,12,30, tzinfo=datetime.timezone.utc)
 
 #-------- Class-based decoratior functions
 def rowcol_method(func):
@@ -1073,10 +1074,17 @@ class Worksheet(googleapps.ServiceClient):
         # todo: should this be rendered as a number in SERIAL__NUMBER format
         # from the docs: The whole number portion of the value (left of the decimal) counts the days since December 30th 1899. The fractional portion (right of the decimal) counts the time as a fraction of the day. For example, January 1st 1900 at noon would be 2.5
         elif t is datetime.date:
-            diff = cell_value - serial_number_base.date()
+            if cell_value.tzname():
+                # --- this is not timezone agnostic
+                diff = cell_value - serial_number_base_utc.date()
+            else:
+                diff = cell_value - serial_number_base.date()
             return({'numberValue': diff.days})
         elif t is datetime.datetime:
-            diff = cell_value - serial_number_base
+            if cell_value.tzname():
+                diff = cell_value - serial_number_base_utc
+            else:
+                diff = cell_value - serial_number_base
             return({'numberValue': diff.total_seconds() / 60 / 60 / 24})
 
         raise TypeError("Unknown type '"+str(t)+"' cannot be processed by update cells for this value: " + str(cell_value))
